Welcome to nbchkr's documentation!
==================================

A lightweight solution to mark/grade/check notebook assignments.

This documentation is in four parts:

- A tutorial: a step by step walk through of writing an assignment, using
  :code:`nbchkr` to create a version to be released and checking submissions.
- A how to guide: a collection of short and to the point instructions for
  carrying out specific tasks.
- A series of explanations: some background information on :code:`nbchkr`.
- A reference section: includes bibliography, a changelog and viewable source code.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tutorial/index.rst
   howto/index.rst
   explanation/index.rst
   reference/index.rst
